==> hyperdex-1.6.0.tar.gz: hyperdex-1.6.0/daemon/index_string.cc <==
// Copyright (c) 2013, Cornell University
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
//     * Redistributions of source code must retain the above copyright notice,
//       this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above copyright
//       notice, this list of conditions and the following disclaimer in the
//       documentation and/or other materials provided with the distribution.
//     * Neither the name of HyperDex nor the names of its contributors may be
//       used to endorse or promote products derived from this software without
//       specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
// CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
// CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
// POSSIBILITY OF SUCH DAMAGE.

// e
#include <e/endian.h>

// HyperDex
#include "daemon/datalayer_encodings.h"
#include "daemon/index_string.h"

using hyperdex::datalayer;
using hyperdex::index_string;
using hyperdex::index_encoding_string;

index_string :: index_string()
    : index_primitive(index_encoding::lookup(HYPERDATATYPE_STRING))
{
}

index_string :: ~index_string() throw ()
{
}

hyperdatatype
index_string :: datatype()
{
    return HYPERDATATYPE_STRING;
}

index_encoding_string :: index_encoding_string()
{
}

index_encoding_string :: ~index_encoding_string() throw ()
{
}

bool
index_encoding_string :: encoding_fixed()
{
    return false;
}

size_t
index_encoding_string :: encoded_size(const e::slice& decoded)
{
    return decoded.size();
}

char*
index_encoding_string :: encode(const e::slice& decoded, char* encoded)
{
    memmove(encoded, decoded.data(), decoded.size());
    return encoded + decoded.size();
}

size_t
index_encoding_string :: decoded_size(const e::slice& encoded)
{
    return encoded.size();
}

char*
index_encoding_string :: decode(const e::slice& encoded, char* decoded)
{
    memmove(decoded, encoded.data(), encoded.size());
    return decoded + encoded.size();
}

==> hyperdex-1.8.1.tar.gz: hyperdex-1.8.1/daemon/index_string.cc <==
// Copyright (c) 2013, Cornell University
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
//     * Redistributions of source code must retain the above copyright notice,
//       this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above copyright
//       notice, this list of conditions and the following disclaimer in the
//       documentation and/or other materials provided with the distribution.
//     * Neither the name of HyperDex nor the names of its contributors may be
//       used to endorse or promote products derived from this software without
//       specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
// CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
// CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
// POSSIBILITY OF SUCH DAMAGE.

// e
#include <e/endian.h>

// HyperDex
#include "daemon/datalayer_encodings.h"
#include "daemon/index_string.h"

using hyperdex::datalayer;
using hyperdex::index_string;
using hyperdex::index_encoding_string;

index_string :: index_string()
    : index_primitive(index_encoding::lookup(HYPERDATATYPE_STRING))
{
}

index_string :: ~index_string() throw ()
{
}

hyperdatatype
index_string :: datatype() const
{
    return HYPERDATATYPE_STRING;
}

index_encoding_string :: index_encoding_string()
{
}

index_encoding_string :: ~index_encoding_string() throw ()
{
}

bool
index_encoding_string :: encoding_fixed() const
{
    return false;
}

size_t
index_encoding_string :: encoded_size(const e::slice& decoded) const
{
    return decoded.size();
}

char*
index_encoding_string :: encode(const e::slice& decoded, char* encoded) const
{
    memmove(encoded, decoded.data(), decoded.size());
    return encoded + decoded.size();
}

size_t
index_encoding_string :: decoded_size(const e::slice& encoded) const
{
    return encoded.size();
}

char*
index_encoding_string :: decode(const e::slice& encoded, char* decoded) const
{
    memmove(decoded, encoded.data(), encoded.size());
    return decoded + encoded.size();
}
